@@ -269,14 +269,14 @@ def test_field_unit_is_none_if_no_units_attribute(nxroot):
     assert field.unit is None
 
 
-@pytest.mark.parametrize('value,type_', [(1.2, float), (123, int), ('abc', str),
-                                         (True, bool)])
+@pytest.mark.parametrize('value,type_', [(1.2, np.float32), (123, np.int32),
+                                         ('abc', str), (True, bool)])
 def test_field_is_returned_as_python_object_if_shape_empty_and_no_unit(
         nxroot, value, type_):
-    nxroot['field1'] = sc.scalar(value, unit=None)
+    nxroot['field1'] = sc.scalar(value, unit=None, dtype=type_)
     field = nxroot['field1'][()]
     assert isinstance(field, type_)
-    assert field == value
+    assert field == type_(value)
 
 
 @pytest.mark.parametrize('value', [1.2, 123, True, 'abc'])
